@@ -1,4 +1,4 @@
-from typing import List, Tuple
+from __future__ import annotations
 import pytest
 from permutation import from_factorial_base, to_factorial_base
 
@@ -60,7 +60,7 @@ FACTORIAL = [
 
 
 @pytest.mark.parametrize("n,digits", FACTORIAL)
-def test_to_factorial_base(n: int, digits: List[int]) -> None:
+def test_to_factorial_base(n: int, digits: list[int]) -> None:
     assert to_factorial_base(n) == digits
 
 
@@ -70,11 +70,11 @@ def test_bad_to_factorial_base() -> None:
 
 
 @pytest.mark.parametrize("n,digits", FACTORIAL)
-def test_from_factorial_base(n: int, digits: List[int]) -> None:
+def test_from_factorial_base(n: int, digits: list[int]) -> None:
     assert from_factorial_base(digits) == n
 
 
 @pytest.mark.parametrize("digits", [(-1,), (2,), (1, 2), (3, 0), (4, 1, 2)])
-def test_bad_from_factorial_base(digits: Tuple[int, ...]) -> None:
+def test_bad_from_factorial_base(digits: tuple[int, ...]) -> None:
     with pytest.raises(ValueError):
         from_factorial_base(digits)
